/*
 * sdl_truetype_font.hpp
 *
 * SDLFont implementation that loads fonts from a truetype file (using SDL_ttf).
 * 
 * Copyright (c) Stephen Thompson, 2008.
 * Licensed for non-commercial use only. See LICENCE.txt for details.
 *
 */

#ifndef SDL_TRUETYPE_FONT_HPP
#define SDL_TRUETYPE_FONT_HPP

#include "sdl_font.hpp"

#include "SDL_ttf.h"

#include <string>
using namespace std;

class SDLTrueTypeFont : public SDLFont {
public:
    // "size" is the point size based on 72DPI, which basically translates to pixel height.
    // Throws InitError if load fails.
    explicit SDLTrueTypeFont(const string& filename, int size);
    ~SDLTrueTypeFont();
    
    // coords relative to top-left of the text.
    virtual void drawText(SDL_Surface *scr, int tl_x, int tl_y, const char *txt,
                          int r, int g, int b) const;

    virtual void getTextSize(const char *txt, int &w, int &h) const;
    virtual int getTextHeight() const;

private:
    TTF_Font* font;
};

#endif
